@@ -1,15 +1,15 @@
 """Array validation."""
-from jsonvl.constants.builtins import Primitive, Collection
+from jsonvl.constants.builtins import Collection, Primitive
 from jsonvl.constants.reserved import Reserved
 from jsonvl.core._array.array_constraints import ArrayConstraints
+from jsonvl.errors import ErrorMessages, JsonSchemaError, JsonValidationError
 from jsonvl.utilities.path_utilities import collect
-from jsonvl.errors import JsonValidationError, ErrorMessages
 
 
 TYPE_NAME = Collection.ARRAY.value
 
 
-def validate_array(data, schema, validator, path):
+def validate_array(data, schema, defs, path, validator):
     """
     Validate a JSON array based on a schema.
 
@@ -25,13 +25,13 @@ def validate_array(data, schema, validator, path):
     elem_schema = schema[Reserved.ELEMENT]
     for i, elem in enumerate(data):
         new_path = f'{path}[{i}]'
-        validator._validate(elem, elem_schema, new_path)
+        validator._validate(elem, elem_schema, defs, new_path)
 
     if Reserved.CONSTRAINTS in schema:
         type_constraints = schema[Reserved.CONSTRAINTS]
         for cons_name, cons_param in type_constraints.items():
             if not ArrayConstraints.has(cons_name):
-                raise JsonValidationError.create(ErrorMessages.INVALID_CONSTRAINT, type=TYPE_NAME, cons=cons_name)
+                raise JsonSchemaError.create(ErrorMessages.INVALID_CONSTRAINT, type=TYPE_NAME, cons=cons_name)
 
             if cons_name == ArrayConstraints.MAX_SIZE.value:
                 _constrain_max_size(cons_name, data, cons_param, path)
@@ -40,7 +40,7 @@ def validate_array(data, schema, validator, path):
             elif cons_name == ArrayConstraints.UNIQUE.value:
                 _constrain_unique(cons_name, data, cons_param, path)
             else:
-                raise JsonValidationError.create(ErrorMessages.INVALID_CONSTRAINT, type=TYPE_NAME, cons=cons_name)
+                raise JsonSchemaError.create(ErrorMessages.INVALID_CONSTRAINT, type=TYPE_NAME, cons=cons_name)
 
 
 def _constrain_unique(cons_name, data, cons_param, path):
@@ -54,8 +54,8 @@ def _constrain_unique(cons_name, data, cons_param, path):
             _constrain_unique(cons_name, data, cons_path, path)
     else:
         valid_types = [Primitive.BOOLEAN.value, Primitive.STRING.value, Collection.ARRAY.value]
-        raise JsonValidationError.create(ErrorMessages.INVALID_CONSTRAINT_PARAM,
-                                         cons=cons_name, param_types=valid_types, param=cons_param)
+        raise JsonSchemaError.create(ErrorMessages.INVALID_CONSTRAINT_PARAM_TYPE,
+                                     cons=cons_name, param_types=valid_types, param=cons_param)
     for x_i, x in enumerate(items):
         for y_i, y in enumerate(items):
             if x_i != y_i and x == y:
@@ -64,8 +64,8 @@ def _constrain_unique(cons_name, data, cons_param, path):
 
 def _constrain_max_size(cons_name, data, cons_param, path):
     if not isinstance(cons_param, int):
-        raise JsonValidationError.create(ErrorMessages.PARAM_NOT_OF_TYPE,
-                                         param=cons_param, cons=cons_name, type='integer')
+        raise JsonSchemaError.create(ErrorMessages.INVALID_CONSTRAINT_PARAM_TYPE,
+                                     param=cons_param, cons=cons_name, param_types=['integer'])
 
     array_size = len(data)
     if array_size > cons_param:
@@ -75,8 +75,8 @@ def _constrain_max_size(cons_name, data, cons_param, path):
 
 def _constrain_min_size(cons_name, data, cons_param, path):
     if not isinstance(cons_param, int):
-        raise JsonValidationError.create(ErrorMessages.PARAM_NOT_OF_TYPE,
-                                         cons=cons_name, param=cons_param, type='integer')
+        raise JsonSchemaError.create(ErrorMessages.INVALID_CONSTRAINT_PARAM_TYPE,
+                                     cons=cons_name, param=cons_param, param_types=['integer'])
 
     array_size = len(data)
     if array_size < cons_param:
