@@ -1,12 +1,12 @@
 """String validation."""
 from jsonvl.constants.builtins import Primitive
-from jsonvl.errors import JsonValidationError, ErrorMessages
+from jsonvl.errors import ErrorMessages, JsonValidationError
 
 
 TYPE_NAME = Primitive.BOOLEAN.value
 
 
-def validate_boolean(data, schema, path):
+def validate_boolean(data, schema, defs, path):
     """
     Validate a JSON boolean based on a schema.
 
